@@ -73,8 +73,8 @@ CairoFonts <- function(regular="Helvetica:style=Regular",bold="Helvetica:style=B
 
 CairoX11 <- function(display=Sys.getenv("DISPLAY"), width = 7, height = 7, pointsize = 12,
 					 gamma = getOption("gamma"), bg = "transparent", canvas = "white",
-					 xpos = NA, ypos = NA) {
-	Cairo(width, height, file=display, type='x11', pointsize=pointsize, bg=bg, units="in", dpi=72)
+					 xpos = NA, ypos = NA, ...) {
+	Cairo(width, height, file=display, type='x11', pointsize=pointsize, bg=bg, units="in", ...)
 }
 
 CairoPNG <- function(filename = "Rplot%03d.png", width = 480, height = 480,
@@ -131,6 +131,6 @@ CairoWin <- function(width = 7, height = 7, pointsize = 12,
 					 bg = "transparent", canvas = "white",
 					 gamma = getOption("gamma"), xpos = NA, ypos = NA,
 					 buffered = getOption("windowsBuffered"),
-					 restoreConsole = FALSE) {
-	Cairo(width, height, '', 'win', pointsize=pointsize, bg=bg, units="in")
+					 restoreConsole = FALSE, ...) {
+	Cairo(width, height, '', 'win', pointsize=pointsize, bg=bg, units="in", ...)
 }
